#[non_exhaustive]pub enum UserProfileUpdate {
Updated(UserProfileChanges),
Dropped,
}Available on crate feature
unstable-msc4262 only.Expand description
An update to a user’s profile.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Updated(UserProfileChanges)
The user’s profile has been updated with the included changes.
Dropped
This user no longer needs to be tracked as they have left all shared rooms.