pub struct UserProfile(/* private fields */);Expand description
All the profile information for a user.
Implementations
Sourceimpl UserProfile
impl UserProfile
Sourcepub fn get(&self, field: &str) -> Option<&JsonValue>
pub fn get(&self, field: &str) -> Option<&JsonValue>
Returns the value of the given profile field.
Sourcepub fn get_static<F: StaticProfileField>(
&self,
) -> Result<Option<F::Value>, Error>
pub fn get_static<F: StaticProfileField>( &self, ) -> Result<Option<F::Value>, Error>
Returns the value of the given StaticProfileField.
Returns Ok(Some(_)) if the field is present and the value was deserialized
successfully, Ok(None) if the field is not set, or an error if deserialization of the
value failed.